@@ -8,11 +8,16 @@
 
 #pragma once
 
+#include "kcmutils_version.h"
 #include "kontactkcmultidialog.h"
 #include <QList>
 #include <QStringList>
 
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
 class KCModuleProxy;
+#else
+class KCModule;
+#endif
 class KPageWidgetItem;
 
 class KontactKCMultiDialogPrivate
@@ -26,11 +31,19 @@ protected:
 
     virtual ~KontactKCMultiDialogPrivate() = default;
 
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
     KCModuleProxy *currentModule = nullptr;
+#else
+    KCModule *currentModule = nullptr;
+#endif
 
     struct CreatedModule {
-        KCModuleProxy *kcm;
-        KPageWidgetItem *item;
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
+        KCModuleProxy *kcm = nullptr;
+#else
+        KCModule *kcm = nullptr;
+#endif
+        KPageWidgetItem *item = nullptr;
         QStringList componentNames;
     };
 
@@ -46,6 +59,11 @@ protected:
 private:
     void init();
     void apply();
+#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
     bool resolveChanges(KCModuleProxy *currentProxy);
     static bool moduleSave(KCModuleProxy *module);
+#else
+    bool resolveChanges(KCModule *currentProxy);
+    static bool moduleSave(KCModule *module);
+#endif
 };
