@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -32,8 +32,11 @@ IntroductionWebEnginePage::IntroductionWebEnginePage(QObject *parent)
     settings()->setAttribute(QWebEngineSettings::FocusOnNavigationEnabled, false);
     settings()->setAttribute(QWebEngineSettings::AllowRunningInsecureContent, false);
     profile()->setPersistentCookiesPolicy(QWebEngineProfile::NoPersistentCookies);
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     const QFontInfo font(QFontDatabase().systemFont(QFontDatabase::GeneralFont));
+#else
+    const QFontInfo font(QFontDatabase::systemFont(QFontDatabase::GeneralFont));
+#endif
     settings()->setFontFamily(QWebEngineSettings::StandardFont, font.family());
     settings()->setFontSize(QWebEngineSettings::DefaultFontSize, font.pixelSize());
 }
